/**
 * @author Eugene Turkov
 * @author <a href="mailto:eugene.turkov@nasa.gov">eugene.turkov@nasa.gov</a>
 * @version: 1.0
 * @since SDK1.5
 * 
 * NASA Ames Research Center Computational Sciences Division Intelligent Data
 * Understanding Group (IDU) Moffett Field, CA 94035
 */

package turkov.io;

import java.io.BufferedWriter;
import java.io.File;
import java.io.FileWriter;
import java.io.IOException;

/**
 * Utility class to aid in writing acii files.
 */
public final class TUTextFileWriter extends FileWriter
{
	public TUTextFileWriter(File file) throws IOException
	{
		super(file);
	}

	/**
	 * Calling this method will cause the given file to be created with each of
	 * the files lines corresponding to the elements of the supplied array.
	 * 
	 * NOTE: If a file exists with the same name, it will be overriden.
	 * 
	 * @param contents
	 *            the contents (line by line) of the file.
	 * @param file
	 *            the file into which the supplied contents will be written.
	 * 
	 * @throws IOException
	 *             if there is a problem related to file IO.
	 */
	public static void createFile(File file, String[] contents)
			throws IOException
	{

		if (file.exists())
			file.delete();

		FileWriter fileWriter = new FileWriter(file);
		BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);

		for (int i = 0; i < contents.length; i++)
		{
			bufferedWriter.write(contents[i].toString());
			if (i != contents.length - 1)
				bufferedWriter.newLine();
		}
		bufferedWriter.flush();
		bufferedWriter.close();
		fileWriter.close();
	}

	/**
	 * Calling this method will cause the given file to be created with each of
	 * the files lines corresponding to the elements of the supplied array.
	 * 
	 * NOTE: If a file exists with the same name, it will be overriden.
	 * 
	 * @param contents
	 *            the contents (line by line) of the file.
	 * @param file
	 *            the file into which the supplied contents will be written.
	 * 
	 * @throws IOException
	 *             if there is a problem related to file IO.
	 */
	public static void createFile(File file, double[][] contents)
			throws IOException
	{
		if (file.exists())
			file.delete();

		FileWriter fileWriter = new FileWriter(file);
		BufferedWriter bufferedWriter = new BufferedWriter(fileWriter);

		for (int row = 0; row < contents.length; row++)
		{
			for (int col = 0; col < contents[row].length; col++)
			{
				bufferedWriter.write(contents[row][col] + "");
				if (col != contents[row].length - 1)
					bufferedWriter.write(" ");
			}

			if (row != contents.length - 1)
			{
				bufferedWriter.newLine();
			}
		}

		bufferedWriter.flush();
		bufferedWriter.close();
		fileWriter.close();

	}

}
